    Mac OS X            	   2                                             ATTR ߄       .                    .  #com.latenitesoft.squeeze.signature   bplist00X$versionX$objectsY$archiverT$top U$null	

^lastCompressedV$class_uncompressedSize#A))-J  Z$classnameX$classes_SQCompressionSignature_SQCompressionSignatureXNSObject_NSKeyedArchiverTroot#-27;AHW^qz|                            